==> dartsv-0.3.0.tar.gz: lib/src/transaction/p2pk_builder.dart <==

import 'package:dartsv/src/transaction/signed_unlock_builder.dart';
import 'package:hex/hex.dart';
import 'package:sprintf/sprintf.dart';

import '../../dartsv.dart';

mixin P2PKLockMixin on _P2PKLockBuilder implements LockingScriptBuilder {

  @override
  SVScript getScriptPubkey(){

    if (signerPubkey == null) return SVScript();

    var pubKeySize = HEX.decode(signerPubkey.toString()).length;
    var scriptString = sprintf("%s 0x%s OP_CHECKSIG", [pubKeySize, signerPubkey.toString()]);

    return SVScript.fromString(scriptString);
  }
}

abstract class _P2PKLockBuilder implements LockingScriptBuilder{
  SVPublicKey signerPubkey;

  _P2PKLockBuilder(this.signerPubkey);

  @override
  SVScript get scriptPubkey => getScriptPubkey();

  @override
  void fromScript(SVScript script) {
    throw UnimplementedError();
  }

}

class P2PKLockBuilder extends _P2PKLockBuilder with P2PKLockMixin{
  P2PKLockBuilder(SVPublicKey signerPubkey) : super(signerPubkey);
}


mixin P2PKUnlockMixin on _P2PKUnlockBuilder implements UnlockingScriptBuilder{

  @override
  SVScript getScriptSig() {

    if (signatures.isEmpty) return SVScript();

    var signatureSize = HEX.decode(signatures[0].toTxFormat()).length;
    var scriptString =sprintf("%s 0x%s", [signatureSize, signatures[0].toTxFormat()]);

    return SVScript.fromString(scriptString);
  }

}

abstract class _P2PKUnlockBuilder extends SignedUnlockBuilder implements UnlockingScriptBuilder{

  _P2PKUnlockBuilder();

  @override
  List<SVSignature> signatures = <SVSignature>[];

  @override
  SVScript get scriptSig => getScriptSig();

  @override
  void fromScript(SVScript script) {
    throw UnimplementedError();
  }

}

class P2PKUnlockBuilder extends _P2PKUnlockBuilder with P2PKUnlockMixin{
  P2PKUnlockBuilder() : super();
}

==> dartsv-0.3.2.tar.gz: lib/src/transaction/p2pk_builder.dart <==

import 'package:dartsv/src/exceptions.dart';
import 'package:dartsv/src/transaction/signed_unlock_builder.dart';
import 'package:hex/hex.dart';
import 'package:sprintf/sprintf.dart';

import '../../dartsv.dart';

mixin P2PKLockMixin on _P2PKLockBuilder implements LockingScriptBuilder {

  @override
  SVScript getScriptPubkey(){

    if (signerPubkey == null) return SVScript();

    var pubKeySize = HEX.decode(signerPubkey.toString()).length;
    var scriptString = sprintf("%s 0x%s OP_CHECKSIG", [pubKeySize, signerPubkey.toString()]);

    return SVScript.fromString(scriptString);
  }
}

abstract class _P2PKLockBuilder implements LockingScriptBuilder{
  SVPublicKey signerPubkey;

  _P2PKLockBuilder(this.signerPubkey);

  //SVScript get scriptPubkey => getScriptPubkey();

  @override
  void fromScript(SVScript script) {

    if (script != null && script.buffer != null) {

      var chunkList = script.chunks;

      if (chunkList.length != 2){
        throw ScriptException("Wrong number of data elements for P2PK ScriptPubkey");
      }

      signerPubkey = SVPublicKey.fromDER(chunkList[0].buf);

    }else{
      throw ScriptException("Invalid Script or Malformed Script.");
    }
  }

}

class P2PKLockBuilder extends _P2PKLockBuilder with P2PKLockMixin{
  P2PKLockBuilder(SVPublicKey signerPubkey) : super(signerPubkey);
}


mixin P2PKUnlockMixin on _P2PKUnlockBuilder implements UnlockingScriptBuilder{

  @override
  SVScript getScriptSig() {

    if (signatures.isEmpty) return SVScript();

    var signatureSize = HEX.decode(signatures[0].toTxFormat()).length;
    var scriptString =sprintf("%s 0x%s", [signatureSize, signatures[0].toTxFormat()]);

    return SVScript.fromString(scriptString);
  }

}

abstract class _P2PKUnlockBuilder extends SignedUnlockBuilder implements UnlockingScriptBuilder{

  _P2PKUnlockBuilder();

  @override
  List<SVSignature> signatures = <SVSignature>[];

  @override
  SVScript get scriptSig => getScriptSig();

  @override
  void fromScript(SVScript script) {
    throw UnimplementedError();
  }

}

class P2PKUnlockBuilder extends _P2PKUnlockBuilder with P2PKUnlockMixin{
  P2PKUnlockBuilder() : super();
}
